@@ -23,10 +23,10 @@ from datetime import datetime, timezone
 from enum import Enum
 
 import boto3
+import requests
 from botocore.exceptions import ClientError
-from retrying import retry
-
 from common.time_utils import seconds
+from retrying import retry
 
 log = logging.getLogger(__name__)
 
@@ -121,7 +121,11 @@ def check_command_output(
     """
     if isinstance(command, str) and not shell:
         command = shlex.split(command)
-    result = _run_command(
+    # A nosec comment is appended to the following line in order to disable the B602 check.
+    # This check is disabled for the following reasons:
+    # - Some callers (e.g., common slurm commands) require the use of `shell=True`.
+    # - All values passed as the command arg are constructed from known inputs.
+    result = _run_command(  # nosec
         lambda _command, _env, _preexec_fn: subprocess.run(
             _command,
             env=_env,
@@ -155,7 +159,11 @@ def run_command(command, env=None, raise_on_error=True, execute_as_user=None, lo
     """
     if isinstance(command, str) and not shell:
         command = shlex.split(command)
-    _run_command(
+    # A nosec comment is appended to the following line in order to disable the B602 check.
+    # This check is disabled for the following reasons:
+    # - Some callers (e.g., common slurm commands) require the use of `shell=True`.
+    # - All values passed as the command arg are constructed from known inputs.
+    _run_command(  # nosec
         lambda _command, _env, _preexec_fn: subprocess.run(
             _command,
             env=_env,
@@ -458,3 +466,28 @@ def load_additional_instance_types_data(config, section):
             except Exception as e:
                 raise CriticalError("Error loading instance types data from configuration: {0}".format(e))
     return instance_types_data
+
+
+def get_metadata(metadata_path):
+    """
+    Get EC2 instance metadata.
+
+    :param metadata_path: the metadata relative path
+    :return the metadata value.
+    """
+    try:
+        token = requests.put(
+            "http://169.254.169.254/latest/api/token", headers={"X-aws-ec2-metadata-token-ttl-seconds": "300"}
+        )
+        headers = {}
+        if token.status_code == requests.codes.ok:
+            headers["X-aws-ec2-metadata-token"] = token.content
+        metadata_url = "http://169.254.169.254/latest/meta-data/{0}".format(metadata_path)
+        metadata_value = requests.get(metadata_url, headers=headers).text
+    except Exception as e:
+        error_msg = "Unable to get {0} metadata. Failed with exception: {1}".format(metadata_path, e)
+        log.critical(error_msg)
+        raise CriticalError(error_msg)
+
+    log.debug("%s=%s", metadata_path, metadata_value)
+    return metadata_value
